@@ -35,6 +35,7 @@ using namespace KScreen;
 
 XRandRConfig::XRandRConfig()
     : QObject()
+    , m_primaryOutput(-1)
     , m_screen(new XRandRScreen(this))
 {
     XRRScreenResources* resources = XRandR::screenResources();
@@ -49,6 +50,9 @@ XRandRConfig::XRandRConfig()
 
         XRandROutput *output = createNewOutput(id, (id == primary));
         m_outputs.insert(id, output);
+        if (id == primary) {
+            m_primaryOutput = output->id();
+        }
     }
 
     XRRFreeScreenResources(resources);
@@ -64,10 +68,14 @@ void XRandRConfig::update()
 
     RROutput primary = XRRGetOutputPrimary(XRandR::display(), XRandR::rootWindow());
 
+    m_primaryOutput = -1;
     XRandROutput::Map::Iterator iter;
     for (iter = m_outputs.begin(); iter != m_outputs.end(); ++iter) {
         XRandROutput *output = iter.value();
         output->update((iter.key() == (int) primary) ? XRandROutput::SetPrimary : XRandROutput::UnsetPrimary);
+        if (iter.key() == (int) primary) {
+            m_primaryOutput = output->id();
+        }
     }
 }
 
@@ -82,11 +90,14 @@ void XRandRConfig::addNewOutput(const RROutput id)
     primary = XRRGetOutputPrimary(XRandR::display(), XRandR::rootWindow());
     XRandROutput *output = createNewOutput(id, (id == primary));
     m_outputs.insert(id, output);
+    if (id == primary) {
+        m_primaryOutput = id;
+    }
 }
 
 XRandROutput* XRandRConfig::createNewOutput(RROutput id, bool primary)
 {
-    XRandROutput *xOutput = new XRandROutput(id, (id == primary), this);
+    XRandROutput *xOutput = new XRandROutput(id, primary, this);
     connect(xOutput, SIGNAL(outputRemoved(int)), SLOT(outputRemovedSlot(int)));
 
     return xOutput;
@@ -114,6 +125,9 @@ KScreen::Config *XRandRConfig::toKScreenConfig() const
 
     config->setOutputs(kscreenOutputs);
     config->setScreen(m_screen->toKScreenScreen(config));
+    if (m_primaryOutput != -1 && config->primaryOutput()->id() != m_primaryOutput) {
+        config->setPrimaryOutput(kscreenOutputs.value(m_primaryOutput));
+    }
 
     return config;
 }
@@ -142,6 +156,10 @@ void XRandRConfig::updateKScreenConfig(Config *config) const
         }
         output->updateKScreenOutput(kscreenOutput);
     }
+
+    if (config->primaryOutput()->id() != m_primaryOutput) {
+        config->setPrimaryOutput(config->output(m_primaryOutput));
+    }
 }
 
 void XRandRConfig::applyKScreenConfig(KScreen::Config *config)
@@ -507,6 +525,12 @@ bool XRandRConfig::disableOutput(Output* output) const
                  0, 0, None, RR_Rotate_0, NULL, 0);
 
     kDebug(dXndr()) << "XRRSetCrtcConfig() returned" << s;
+
+    // Update the cached output now, otherwise we get RRNotify_CrtcChange notification
+    // for an outdated output, which can lead to a crash.
+    if (s == RRSetConfigSuccess) {
+        m_outputs.value(output->id())->update();
+    }
     return (s == RRSetConfigSuccess);
 }
 
