@@ -1,19 +1,19 @@
 /*************************************************************************************
  *  Copyright (C) 2012 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
  *                                                                                   *
- *  This program is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU General Public License                      *
- *  as published by the Free Software Foundation; either version 2                   *
- *  of the License, or (at your option) any later version.                           *
+ *  This library is free software; you can redistribute it and/or                    *
+ *  modify it under the terms of the GNU Lesser General Public                       *
+ *  License as published by the Free Software Foundation; either                     *
+ *  version 2.1 of the License, or (at your option) any later version.               *
  *                                                                                   *
- *  This program is distributed in the hope that it will be useful,                  *
+ *  This library is distributed in the hope that it will be useful,                  *
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
- *  GNU General Public License for more details.                                     *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
+ *  Lesser General Public License for more details.                                  *
  *                                                                                   *
- *  You should have received a copy of the GNU General Public License                *
- *  along with this program; if not, write to the Free Software                      *
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
+ *  You should have received a copy of the GNU Lesser General Public                 *
+ *  License along with this library; if not, write to the Free Software              *
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
  *************************************************************************************/
 
 #ifndef OUTPUT_CONFIG_H
@@ -28,6 +28,7 @@
 #include <QtCore/QMetaType>
 #include <QtCore/QPointer>
 #include <QtCore/QStringList>
+#include <QtCore/QDebug>
 
 namespace KScreen {
 
@@ -54,6 +55,7 @@ class KSCREEN_EXPORT Output : public QObject
         Q_PROPERTY(bool primary READ isPrimary WRITE setPrimary NOTIFY isPrimaryChanged)
         Q_PROPERTY(QList<int> clones READ clones WRITE setClones NOTIFY clonesChanged)
         Q_PROPERTY(KScreen::Edid* edid READ edid CONSTANT)
+        Q_PROPERTY(QSize sizeMm READ sizeMm CONSTANT)
 
         enum Type {
             Unknown,
@@ -83,6 +85,8 @@ class KSCREEN_EXPORT Output : public QObject
         explicit Output(QObject *parent = 0);
         virtual ~Output();
 
+        Output* clone() const;
+
         int id() const;
         void setId(int id);
 
@@ -141,6 +145,8 @@ class KSCREEN_EXPORT Output : public QObject
 
         Edid* edid() const;
 
+        QSize sizeMm() const;
+        void setSizeMm(const QSize &size);
     Q_SIGNALS:
         void outputChanged();
         void posChanged();
@@ -157,12 +163,16 @@ class KSCREEN_EXPORT Output : public QObject
         class Private;
         Private * const d;
 
+        Output(Private *dd);
+
 };
 
 typedef QHash<int, Output*> OutputList;
 
 } //KScreen namespace
 
+KSCREEN_EXPORT QDebug operator<<(QDebug dbg, const KScreen::Output *output);
+
 Q_DECLARE_METATYPE(KScreen::OutputList)
 Q_DECLARE_METATYPE(KScreen::Output::Rotation)
 Q_DECLARE_METATYPE(KScreen::Output::Type)
